PCB Environment: py::DictIterator Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
py::DictIterator Struct Reference

## Public Member Functions
| DictIterator (PyObject *py)
bool | next ()

## Data Fields
Object | d
Object | k
Object | v
Py_ssize_t | pos {0}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/PyObject.hpp